@@ -1,7 +1,7 @@
 /* -*- Mode: C; c-basic-offset: 2; indent-tabs-mode: nil -*- */
 
 /*
- * Copyright (C) 2000-2018 the xine project
+ * Copyright (C) 2000-2008 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -143,8 +143,6 @@ static void __xine_pa_stream_request_callback(pa_stream *s, size_t nbytes, void
 {
   pulse_driver_t * this = (pulse_driver_t*) this_gen;
 
-  (void)s;
-  (void)nbytes;
   pa_threaded_mainloop_signal(this->mainloop, 0);
 }
 
@@ -158,7 +156,6 @@ static void __xine_pa_stream_notify_callback(pa_stream *s, void *this_gen)
 {
   pulse_driver_t * this = (pulse_driver_t*) this_gen;
 
-  (void)s;
   pa_threaded_mainloop_signal(this->mainloop, 0);
 }
 
@@ -173,7 +170,6 @@ static void __xine_pa_stream_success_callback(pa_stream *s, int success, void *t
 {
   pulse_driver_t * this = (pulse_driver_t*) this_gen;
 
-  (void)s;
   if (!success)
     xprintf (this->xine, XINE_VERBOSITY_DEBUG, "audio_pulse_out: stream operation failed: %s\n", pa_strerror(pa_context_errno(this->context)));
 
@@ -191,7 +187,6 @@ static void __xine_pa_context_success_callback(pa_context *c, int success, void
 {
   pulse_driver_t *this = (pulse_driver_t*) this_gen;
 
-  (void)c;
   if (!success)
     xprintf (this->xine, XINE_VERBOSITY_DEBUG, "audio_pulse_out: context operation failed: %s\n", pa_strerror(pa_context_errno(this->context)));
 
@@ -215,7 +210,6 @@ static void __xine_pa_sink_info_callback(pa_context *c, const pa_sink_input_info
 
   pulse_driver_t *const this = (pulse_driver_t *) userdata;
 
-  (void)c;
   if (is_last < 0) {
     xprintf (this->xine, XINE_VERBOSITY_DEBUG, "audio_pulse_out: Failed to get sink input info: %s\n",
              pa_strerror(pa_context_errno(this->context)));
@@ -250,8 +244,9 @@ static void __xine_pa_sink_info_callback(pa_context *c, const pa_sink_input_info
   event.data_length = sizeof(data);
 
   pthread_mutex_lock(&this->xine->streams_lock);
-  ite = NULL;
-  while ((stream = xine_list_next_value (this->xine->streams, &ite))) {
+  for(ite = xine_list_front(this->xine->streams); ite; ite =
+    xine_list_next(this->xine->streams, ite)) {
+    stream = xine_list_get_value(this->xine->streams, ite);
     event.stream = stream;
     xine_event_send(stream, &event);
   }
@@ -270,9 +265,8 @@ static void __xine_pa_context_subscribe_callback(pa_context *c,
     pa_subscription_event_type_t t, uint32_t idx, void *this_gen)
 {
   pulse_driver_t * this = (pulse_driver_t*) this_gen;
-  uint32_t index;
+  int index;
 
-  (void)c;
   if (this->stream == NULL)
     return;
 
@@ -313,10 +307,7 @@ static int connect_context(pulse_driver_t *this) {
       p = "Xine";
 
     this->context = pa_context_new(pa_threaded_mainloop_get_api(this->mainloop), p);
-    if (!this->context) {
-      xprintf (this->xine, XINE_VERBOSITY_DEBUG, "audio_pulse_out: pa_context_new() failed\n");
-      return -1;
-    }
+    _x_assert(this->context);
 
     pa_context_set_state_callback(this->context, __xine_pa_context_state_callback, this);
 
@@ -358,7 +349,6 @@ static int connect_context(pulse_driver_t *this) {
      return -1;
   }
 
-  pa_operation_unref(operation);
   return 0;
 }
 
@@ -419,8 +409,7 @@ static int ao_pulse_open(ao_driver_t *this_gen,
       ss.format = PA_SAMPLE_FLOAT32NE;
       break;
     default:
-      xprintf (this->xine, XINE_VERBOSITY_DEBUG, "audio_pulse_out: unsupported bit depth %u\n", bits);
-      goto fail;
+      _x_assert(!"Should not be reached");
   }
 
 #if PA_CHECK_VERSION(1,0,0)
@@ -473,8 +462,7 @@ static int ao_pulse_open(ao_driver_t *this_gen,
       cm.channels = 6;
       break;
     default:
-      xprintf (this->xine, XINE_VERBOSITY_DEBUG, "audio_pulse_out: unsupported mode %08x\n", mode);
-      goto fail;
+      _x_assert(!"Should not be reached");
   }
 
   if (!pa_channel_map_valid(&cm)) {
@@ -514,6 +502,7 @@ static int ao_pulse_open(ao_driver_t *this_gen,
 
   _x_assert(!this->stream);
   this->stream = pa_stream_new_extended(this->context, "Audio Stream", formatv, formatc, proplist);
+  _x_assert(this->stream);
 
   if (proplist != NULL)
     pa_proplist_free(proplist);
@@ -524,13 +513,9 @@ static int ao_pulse_open(ao_driver_t *this_gen,
 #else
   _x_assert(!this->stream);
   this->stream = pa_stream_new(this->context, "Audio Stream", &ss, &cm);
+  _x_assert(this->stream);
 #endif
 
-  if (!this->stream) {
-    xprintf (this->xine, XINE_VERBOSITY_DEBUG, "audio_pulse_out: pa_Stream_new() failed\n");
-    goto fail;
-  }
-
   pa_stream_set_state_callback(this->stream, __xine_pa_stream_state_callback, this);
   pa_stream_set_write_callback(this->stream, __xine_pa_stream_request_callback, this);
   pa_stream_set_latency_update_callback(this->stream, __xine_pa_stream_notify_callback, this);
@@ -559,16 +544,17 @@ static int ao_pulse_open(ao_driver_t *this_gen,
   if (encoding != PA_ENCODING_INVALID) {
     const pa_format_info *info = pa_stream_get_format_info(this->stream);
 
-    if (info) {
-      if (pa_format_info_is_pcm (info)) {
-        xprintf (this->xine, XINE_VERBOSITY_DEBUG, "digital pass-through not available\n");
-      } else {
-        xprintf (this->xine, XINE_VERBOSITY_DEBUG, "digital pass-through enabled\n");
-      }
+    _x_assert(info);
+    if (pa_format_info_is_pcm (info)) {
+      xprintf (this->xine, XINE_VERBOSITY_DEBUG, "digital pass-through not available\n");
+    } else {
+      xprintf (this->xine, XINE_VERBOSITY_DEBUG, "digital pass-through enabled\n");
     }
   }
 #endif
 
+  pa_threaded_mainloop_unlock(this->mainloop);
+
   /* Now we must handle a problem: at init time, xine might have tried to set the default volume value
    * This won't work with pulseaudio, because, at that time, pulseaudio doesn't have a stream.
    * As a workaround, we re-do the volume thingie here */
@@ -607,8 +593,6 @@ static int ao_pulse_open(ao_driver_t *this_gen,
 
   pa_operation_unref(operation);
 
-  pa_threaded_mainloop_unlock(this->mainloop);
-
   return this->sample_rate;
 
  fail:
@@ -633,7 +617,6 @@ static int ao_pulse_bytes_per_frame(ao_driver_t *this_gen)
 
 static int ao_pulse_get_gap_tolerance (ao_driver_t *this_gen)
 {
-  (void)this_gen;
   return GAP_TOLERANCE;
 }
 
@@ -950,7 +933,6 @@ static ao_driver_t *open_plugin (audio_driver_class_t *class_gen, const void *da
 
   lprintf ("audio_pulse_out: open_plugin called\n");
 
-  (void)data;
   this = calloc(1, sizeof (pulse_driver_t));
   if (!this)
     return NULL;
@@ -1005,13 +987,8 @@ static ao_driver_t *open_plugin (audio_driver_class_t *class_gen, const void *da
     }
   }
 
-  _x_assert(!this->mainloop);
   this->mainloop = pa_threaded_mainloop_new();
-  if (!this->mainloop) {
-    xprintf (this->xine, XINE_VERBOSITY_DEBUG, "audio_pulse_out: pa_threaded_mainloop_new() failed\n");
-    ao_pulse_exit((ao_driver_t *) this);
-    return NULL;
-  }
+  _x_assert(this->mainloop);
   pa_threaded_mainloop_start(this->mainloop);
 
   /*
@@ -1075,13 +1052,12 @@ static void dispose_class (audio_driver_class_t *this_gen) {
   free(this);
 }
 
-static void *init_class (xine_t *xine, const void *data) {
+static void *init_class (xine_t *xine, void *data) {
 
   pulse_class_t        *this;
 
   lprintf ("audio_pulse_out: init class\n");
 
-  (void)data;
   this = calloc(1, sizeof (pulse_class_t));
   if (!this)
     return NULL;
@@ -1096,7 +1072,7 @@ static void *init_class (xine_t *xine, const void *data) {
 }
 
 static const ao_info_t ao_info_pulse = {
-  .priority = 12,
+  12
 };
 
 /*
@@ -1106,7 +1082,5 @@ static const ao_info_t ao_info_pulse = {
 const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */
   { PLUGIN_AUDIO_OUT, 9, "pulseaudio", XINE_VERSION_CODE, &ao_info_pulse, init_class },
-  { PLUGIN_NONE, 0, NULL, 0, NULL, NULL }
+  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
-
-
