@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2017 the xine project
+ * Copyright (C) 2000-2003 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -156,7 +156,7 @@ static int demux_nsf_send_chunk(demux_plugin_t *this_gen) {
 
       buf->decoder_info[1] = this->current_song;
       this->new_song = 0;
-      snprintf(title, sizeof(title), "%s, song %d/%d",
+      sprintf(title, "%s, song %d/%d",
         this->title, this->current_song, this->total_songs);
 
       _x_meta_info_set(this->stream, XINE_META_INFO_TITLE, title);
@@ -202,7 +202,7 @@ static void demux_nsf_send_headers(demux_plugin_t *this_gen) {
 
   _x_meta_info_set(this->stream, XINE_META_INFO_TITLE, this->title);
   _x_meta_info_set(this->stream, XINE_META_INFO_ARTIST, this->artist);
-  snprintf(copyright, sizeof(copyright), "(C) %s", this->copyright);
+  sprintf(copyright, "(C) %s", this->copyright);
   _x_meta_info_set(this->stream, XINE_META_INFO_COMMENT, copyright);
 
   /* send start buffers */
