@@ -1,6 +1,6 @@
 
 /*
- * Copyright (C) 2000-2017 the xine project
+ * Copyright (C) 2000-2003 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -146,12 +146,12 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <string.h>
+#include <arpa/inet.h>
 
-#ifdef HAVE_ARPA_INET_H
-#include <arpa/inet.h>  /* htonl */
-#endif
-#ifdef _WIN32
-#include <winsock.h>    /* htonl */
+#ifdef HAVE_FFMPEG_AVUTIL_H
+#  include <crc.h>
+#else
+#  include <libavutil/crc.h>
 #endif
 
 #define LOG_MODULE "demux_ts"
@@ -159,9 +159,6 @@
 /*
 #define LOG
 */
-/* #define LOG_DYNAMIC_PMT */
-
-#include "group_video.h"
 
 #include <xine/xine_internal.h>
 #include <xine/xineutils.h>
@@ -245,8 +242,6 @@
       ISO_14496_PART2_VIDEO = 0x10,     /* ISO/IEC 14496-2 Visual (MPEG-4) */
       ISO_14496_PART3_AUDIO = 0x11,     /* ISO/IEC 14496-3 Audio with LATM transport syntax */
       ISO_14496_PART10_VIDEO = 0x1b,    /* ISO/IEC 14496-10 Video (MPEG-4 part 10/AVC, aka H.264) */
-      STREAM_VIDEO_HEVC = 0x24,
-
       STREAM_VIDEO_MPEG      = 0x80,
       STREAM_AUDIO_AC3       = 0x81,
 
@@ -342,6 +337,7 @@ typedef struct {
   xine_t           *xine;
   config_values_t  *config;
 
+  const AVCRC      *av_crc;
 } demux_ts_class_t;
 
 typedef struct {
@@ -761,10 +757,10 @@ static void demux_ts_update_spu_channel(demux_ts_t *this)
 #endif
     }
 
-  if ((this->media[this->spu_media].type & (BUF_MAJOR_MASK | BUF_DECODER_MASK)) == BUF_SPU_HDMV) {
-    buf->type = BUF_SPU_HDMV;
-    buf->type |= this->current_spu_channel;
-  }
+ if ((this->media[this->spu_media].type & BUF_MAJOR_MASK) == BUF_SPU_HDMV) {
+   buf->type = BUF_SPU_HDMV;
+   buf->type |= this->current_spu_channel;
+ }
 
   this->video_fifo->put(this->video_fifo, buf);
 }
@@ -939,7 +935,7 @@ static void demux_ts_parse_pat (demux_ts_t*this, unsigned char *original_pkt,
   crc32 |= (uint32_t) pkt[section_length - 2] << 8;
   crc32 |= (uint32_t) pkt[section_length - 1];
 
-  calc_crc32 = htonl (xine_crc32_ieee (0xffffffff, pkt, section_length - 4));
+  calc_crc32 = htonl (av_crc (this->class->av_crc, 0xffffffff, pkt, section_length - 4));
   if (crc32 != calc_crc32) {
     xprintf (this->stream->xine, XINE_VERBOSITY_DEBUG,
 	     "demux_ts: demux error! PAT with invalid CRC32: packet_crc32: %.8x calc_crc32: %.8x\n",
@@ -1102,11 +1098,6 @@ static int demux_ts_parse_pes_header (xine_t *xine, demux_ts_media *m,
     return header_len;
   }
 
-  if (m->descriptor_tag == STREAM_VIDEO_HEVC) {
-    m->type      = BUF_VIDEO_HEVC;
-    return header_len;
-  }
-
   if (m->descriptor_tag == HDMV_SPU_BITMAP) {
     m->type |= BUF_SPU_HDMV;
     m->buf->decoder_info[2] = m->pes_bytes_left;
@@ -1328,7 +1319,7 @@ static void demux_ts_buffer_pes(demux_ts_t*this, unsigned char *ts,
       m->buf->free_buffer(m->buf);
       m->buf = NULL;
 
-      m->corrupted_pes = 1;
+      m->corrupted_pes++;
       xprintf(this->stream->xine, XINE_VERBOSITY_DEBUG,
               "demux_ts: PID 0x%.4x: corrupted pes encountered\n", m->pid);
     } else {
@@ -1350,58 +1341,22 @@ static void demux_ts_buffer_pes(demux_ts_t*this, unsigned char *ts,
   }
 
   if (!m->corrupted_pes) {
-    int room = m->buf->max_size - m->buf->size;
 
-    if (len > room) {
-      if (room > 0)
-        memcpy (m->buf->mem + m->buf->size, ts, room);
-      m->pes_bytes_left -= m->buf->max_size;
-      m->buf->size = m->buf->max_size;
-      demux_ts_send_buffer (m, 0);
-      m->buf = m->fifo->buffer_pool_alloc (m->fifo);
-      m->buf->decoder_flags = BUF_FLAG_MERGE;
-      memcpy (m->buf->mem, ts + room, len - room);
-      m->buf->size = len - room;
-    } else {
-      memcpy (m->buf->mem + m->buf->size, ts, len);
-      m->buf->size += len;
+    if ((m->buf->size + len) > m->buf->max_size) {
+      m->pes_bytes_left -= m->buf->size;
+      demux_ts_send_buffer(m, 0);
+      m->buf = m->fifo->buffer_pool_alloc(m->fifo);
     }
 
+    memcpy(m->buf->mem + m->buf->size, ts, len);
+    m->buf->size += len;
+
     if (m->pes_bytes_left > 0 && m->buf->size >= m->pes_bytes_left) {
       /* PES payload complete */
       m->pes_bytes_left -= m->buf->size;
       demux_ts_flush_media(m);
       /* skip rest data - there shouldn't be any */
       m->corrupted_pes = 1;
-    } else {
-
-      /* If video data ends to sequence end code, flush buffer. */
-      /* (there won't be any more data -> no pusi -> last buffer is never flushed) */
-      if (m->pid == this->videoPid && m->buf->size > 4 && m->buf->mem[m->buf->size-4] == 0) {
-
-        if (m->type == BUF_VIDEO_MPEG) {
-          if (!memcmp(&m->buf->mem[m->buf->size-4], "\x00\x00\x01\xb7", 4)) {
-            xprintf(this->stream->xine, XINE_VERBOSITY_DEBUG,
-                    "demux_ts: PID 0x%.4x: flushing after MPEG end of sequence code\n", m->pid);
-            demux_ts_flush_media(m);
-          }
-
-        } else if (m->type == BUF_VIDEO_H264) {
-          if ((!memcmp(&m->buf->mem[m->buf->size-4], "\x00\x00\x01\x0a", 4)) ||
-              (m->buf->size > 5 &&
-               !memcmp(&m->buf->mem[m->buf->size-5], "\x00\x00\x01\x0a", 4))) {
-            xprintf(this->stream->xine, XINE_VERBOSITY_DEBUG,
-                    "demux_ts: PID 0x%.4x: flushing after H.264 end of sequence code\n", m->pid);
-            demux_ts_flush_media(m);
-          }
-        } else if (m->type == BUF_VIDEO_VC1) {
-          if (!memcmp(&m->buf->mem[m->buf->size-4], "\x00\x00\x01\x0a", 4)) {
-            xprintf(this->stream->xine, XINE_VERBOSITY_DEBUG,
-                    "demux_ts: PID 0x%.4x: flushing after VC-1 end of sequence code\n", m->pid);
-            demux_ts_flush_media(m);
-          }
-        }
-      }
     }
   }
 }
@@ -1596,7 +1551,7 @@ static void demux_ts_parse_pmt (demux_ts_t     *this,
   crc32 |= (uint32_t) pkt[section_length - 2] << 8;
   crc32 |= (uint32_t) pkt[section_length - 1];
 
-  calc_crc32 = htonl (xine_crc32_ieee (0xffffffff, pkt, section_length - 4));
+  calc_crc32 = htonl (av_crc (this->class->av_crc, 0xffffffff, pkt, section_length - 4));
   if (crc32 != calc_crc32) {
     xprintf (this->stream->xine, XINE_VERBOSITY_DEBUG,
       "demux_ts: demux error! PMT with invalid CRC32: packet_crc32: %#.8x calc_crc32: %#.8x\n",
@@ -1684,7 +1639,6 @@ printf("Program Number is %i, looking for %i\n",program_number,this->program_num
     case ISO_13818_VIDEO:
     case ISO_14496_PART2_VIDEO:
     case ISO_14496_PART10_VIDEO:
-    case STREAM_VIDEO_HEVC:
     case STREAM_VIDEO_VC1:
       if (this->videoPid == INVALID_PID) {
 #ifdef TS_PMT_LOG
@@ -1732,19 +1686,6 @@ printf("Program Number is %i, looking for %i\n",program_number,this->program_num
 #endif
       break;
     case ISO_13818_PES_PRIVATE:
-      {
-        uint32_t format_identifier=0;
-        demux_ts_get_reg_desc(this, &format_identifier, stream + 5, stream_info_length);
-        if (format_identifier == 0x48455643 /* HEVC */ ) {
-          mi = demux_ts_dynamic_pmt_find (this, pid, BUF_VIDEO_BASE, STREAM_VIDEO_HEVC);
-          if (mi >= 0) {
-            this->videoMedia = mi;
-            this->videoPid = pid;
-          }
-          break;
-        }
-      }
-
       for (i = 5; i < coded_length; i += stream[i+1] + 2) {
 
         if ((stream[i] == DESCRIPTOR_AC3) || (stream[i] == DESCRIPTOR_EAC3) || (stream[i] == DESCRIPTOR_DTS)) {
@@ -1886,11 +1827,6 @@ printf("Program Number is %i, looking for %i\n",program_number,this->program_num
           }
         }
       }
-
-      xprintf(this->stream->xine, XINE_VERBOSITY_DEBUG,
-              "demux_ts: PMT unknown stream_type: 0x%.2x pid: 0x%.4x\n",
-              stream[0], pid);
-
 #ifdef TS_PMT_LOG
       printf ("demux_ts: PMT unknown stream_type: 0x%.2x pid: 0x%.4x\n",
               stream[0], pid);
@@ -2308,8 +2244,8 @@ static void demux_ts_parse_packet (demux_ts_t*this) {
 
   /* PMT */
   program_count=0;
-  while (program_count < MAX_PMTS &&
-          (this->program_number[program_count] != INVALID_PROGRAM)) {
+  while ((this->program_number[program_count] != INVALID_PROGRAM) &&
+         (program_count < MAX_PMTS)) {
     if (pid == this->pmt_pid[program_count]) {
 
 #ifdef TS_LOG
@@ -2545,12 +2481,6 @@ static int demux_ts_seek (demux_plugin_t *this_gen,
     this->buf_flag_seek = 1;
     _x_demux_flush_engine(this->stream);
 
-    /* Append sequence end code to video stream. */
-    /* Keep ffmpeg h.264 video decoder from piling up too many DR1 frames, */
-    /* and thus freezing video out. */
-    if (this->videoPid != INVALID_PID && this->stream->video_fifo)
-      post_sequence_end (this->stream->video_fifo, this->media[this->videoMedia].type);
-
   }
 
   demux_ts_tbre_reset (this);
@@ -2561,13 +2491,12 @@ static int demux_ts_seek (demux_plugin_t *this_gen,
 static int demux_ts_get_stream_length (demux_plugin_t *this_gen) {
 
   demux_ts_t*this = (demux_ts_t*)this_gen;
-  int rate = this->rate;
 
-  if (rate)
+  if (this->rate)
     return (int)((int64_t) this->input->get_length (this->input)
-                 * 1000 / rate);
-
-  return 0;
+                 * 1000 / this->rate);
+  else
+    return 0;
 }
 
 
@@ -2757,7 +2686,7 @@ static demux_plugin_t *open_plugin (demux_class_t *class_gen,
 /*
  * ts demuxer class
  */
-void *demux_ts_init_class (xine_t *xine, void *data) {
+static void *init_class (xine_t *xine, void *data) {
 
   demux_ts_class_t     *this;
 
@@ -2777,6 +2706,22 @@ void *demux_ts_init_class (xine_t *xine, void *data) {
   this->demux_class.extensions      = "ts m2t trp m2ts mts dvb:// dvbs:// dvbc:// dvbt://";
   this->demux_class.dispose         = default_demux_class_dispose;
 
+  this->av_crc = av_crc_get_table(AV_CRC_32_IEEE);
+
   return this;
 }
 
+
+/*
+ * exported plugin catalog entry
+ */
+static const demuxer_info_t demux_info_ts = {
+  10                       /* priority */
+};
+
+const plugin_info_t xine_plugin_info[] EXPORTED = {
+  /* type, API, "name", version, special_info, init_function */
+  { PLUGIN_DEMUX, 27, "mpeg-ts", XINE_VERSION_CODE, &demux_info_ts, init_class },
+  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
+};
+
