@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2018 the xine project
+ * Copyright (C) 2000-2003 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -36,9 +36,6 @@
 #include <string.h>
 #include <stdlib.h>
 
-#define LOG_MODULE "demux_yuv4mpeg2"
-#include "group_video.h"
-
 #include <xine/xine_internal.h>
 #include <xine/xineutils.h>
 #include <xine/compat.h>
@@ -80,6 +77,9 @@ typedef struct {
   int                  seek_flag;
 } demux_yuv4mpeg2_t;
 
+typedef struct {
+  demux_class_t     demux_class;
+} demux_yuv4mpeg2_class_t;
 
 /* returns 1 if the YUV4MPEG2 file was opened successfully, 0 otherwise */
 static int open_yuv4mpeg2_file(demux_yuv4mpeg2_t *this) {
@@ -211,13 +211,11 @@ static int open_yuv4mpeg2_file(demux_yuv4mpeg2_t *this) {
   this->frame_pts_inc = (90000 * this->fps_d) / this->fps_n;
 
   /* finally, look for the first frame */
-  size_t left = (size_t)Y4M_HEADER_BYTES - (size_t)(header_ptr - header);
-  char *data_start_ptr = memmem(header_ptr, left, "FRAME", 5);
+  char *data_start_ptr = memmem(header_ptr, Y4M_HEADER_BYTES, "FRAME", 5);
 
   /* make sure the first frame was found */
-  if ( !data_start_ptr ) {
+  if ( !data_start_ptr )
     return 0;
-  }
 
   this->data_start = data_start_ptr - header;
 
@@ -228,8 +226,7 @@ static int open_yuv4mpeg2_file(demux_yuv4mpeg2_t *this) {
   }
 
   /* file is qualified; seek to first frame */
-  if (this->input->seek(this->input, this->data_start, SEEK_SET) != this->data_start)
-    return 0;
+  this->input->seek(this->input, this->data_start, SEEK_SET);
 
   return 1;
 }
@@ -267,7 +264,7 @@ static int demux_yuv4mpeg2_send_chunk(demux_plugin_t *this_gen) {
   }
 
   while(bytes_remaining) {
-    buf_element_t *buf = this->video_fifo->buffer_pool_size_alloc (this->video_fifo, bytes_remaining);
+    buf_element_t *buf = this->video_fifo->buffer_pool_alloc (this->video_fifo);
     buf->type = BUF_VIDEO_I420;
     if( this->data_size )
       buf->extra_info->input_normpos = (int)((double) current_file_pos * 65535 / this->data_size);
@@ -389,26 +386,17 @@ static int demux_yuv4mpeg2_get_stream_length (demux_plugin_t *this_gen) {
 }
 
 static uint32_t demux_yuv4mpeg2_get_capabilities(demux_plugin_t *this_gen) {
-  (void)this_gen;
   return DEMUX_CAP_NOCAP;
 }
 
 static int demux_yuv4mpeg2_get_optional_data(demux_plugin_t *this_gen,
 					void *data, int data_type) {
-  (void)this_gen;
-  (void)data;
-  (void)data_type;
   return DEMUX_OPTIONAL_UNSUPPORTED;
 }
 
 static demux_plugin_t *open_plugin (demux_class_t *class_gen, xine_stream_t *stream,
                                     input_plugin_t *input) {
-  demux_yuv4mpeg2_t *this;
-
-  this = calloc(1, sizeof(demux_yuv4mpeg2_t));
-  if (!this)
-    return NULL;
-
+  demux_yuv4mpeg2_t *this = calloc(1, sizeof(demux_yuv4mpeg2_t));
   this->stream = stream;
   this->input  = input;
 
@@ -445,20 +433,30 @@ static demux_plugin_t *open_plugin (demux_class_t *class_gen, xine_stream_t *str
   return &this->demux_plugin;
 }
 
-void *demux_yuv4mpeg2_init_class (xine_t *xine, const void *data) {
+static void *init_plugin (xine_t *xine, void *data) {
+  demux_yuv4mpeg2_class_t     *this;
 
-  (void)xine;
-  (void)data;
+  this = calloc(1, sizeof(demux_yuv4mpeg2_class_t));
 
-  static const demux_class_t demux_yuv4mpeg2_class = {
-    .open_plugin     = open_plugin,
-    .description     = N_("YUV4MPEG2 file demux plugin"),
-    .identifier      = "YUV4MPEG2",
-    .mimetypes       = NULL,
-    .extensions      = "y4m",
-    .dispose         = NULL,
-  };
+  this->demux_class.open_plugin     = open_plugin;
+  this->demux_class.description     = N_("YUV4MPEG2 file demux plugin");
+  this->demux_class.identifier      = "YUV4MPEG2";
+  this->demux_class.mimetypes       = NULL;
+  this->demux_class.extensions      = "y4m";
+  this->demux_class.dispose         = default_demux_class_dispose;
 
-  return (void *)&demux_yuv4mpeg2_class;
+  return this;
 }
 
+/*
+ * exported plugin catalog entry
+ */
+static const demuxer_info_t demux_info_yuv4mpeg2 = {
+  10                       /* priority */
+};
+
+const plugin_info_t xine_plugin_info[] EXPORTED = {
+  /* type, API, "name", version, special_info, init_function */
+  { PLUGIN_DEMUX, 27, "yuv4mpeg2", XINE_VERSION_CODE, &demux_info_yuv4mpeg2, init_plugin },
+  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
+};
