@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2021 the xine project
+ * Copyright (C) 2000-2005 the xine project
  * March 2003 - Miguel Freitas
  * This plugin was sponsored by 1Control
  *
@@ -165,10 +165,22 @@ struct ivtv_ioctl_codec {
 
 typedef struct pvrscr_s pvrscr_t;
 
+typedef struct {
+
+  input_class_t     input_class;
+
+  xine_t           *xine;
+  config_values_t  *config;
+
+  char             *devname;
+
+} pvr_input_class_t;
+
+
 typedef struct {
   input_plugin_t      input_plugin;
 
-  char               *devname;
+  pvr_input_class_t  *class;
 
   xine_stream_t      *stream;
 
@@ -265,7 +277,6 @@ struct pvrscr_s {
 };
 
 static int pvrscr_get_priority (scr_plugin_t *scr) {
-  (void)scr;
   return 10; /* high priority */
 }
 
@@ -375,8 +386,6 @@ static pvrscr_t *XINE_MALLOC pvrscr_init (void) {
   pvrscr_t *this;
 
   this = calloc(1, sizeof(pvrscr_t));
-  if (!this)
-    return NULL;
 
   this->scr.interface_version = 3;
   this->scr.get_priority      = pvrscr_get_priority;
@@ -414,16 +423,14 @@ static uint32_t pvr_plugin_get_capabilities (input_plugin_t *this_gen) {
 
   /* pvr_input_plugin_t *this = (pvr_input_plugin_t *) this_gen; */
 
-  (void)this_gen;
   return INPUT_CAP_BLOCK | INPUT_CAP_SEEKABLE;
 }
 
 
 static off_t pvr_plugin_read (input_plugin_t *this_gen, void *buf_gen, off_t len) {
   /*pvr_input_plugin_t *this = (pvr_input_plugin_t *) this_gen;*/
-  uint8_t *buf = buf_gen;
+  char *buf = (char *)buf_gen;
 
-  (void)this_gen;
   if (len < 4)
     return -1;
 
@@ -600,10 +607,7 @@ static int pvr_break_rec_page (pvr_input_plugin_t *this) {
       this->play_fd = -1;
     }
 
-    if (remove(filename) < 0) {
-      xprintf(this->stream->xine, XINE_VERBOSITY_LOG,
-              "input_pvr: error removing pvr file (%s)\n", filename);
-    }
+    remove(filename);
     free(filename);
   }
   return 1;
@@ -625,12 +629,12 @@ static int pvr_rec_file(pvr_input_plugin_t *this) {
       return 0;
   }
   pos = (off_t)(this->rec_blk - this->page_block[this->rec_page]) * PVR_BLOCK_SIZE;
+  if( lseek (this->rec_fd, pos, SEEK_SET) != pos ) {
+    xprintf(this->stream->xine, XINE_VERBOSITY_DEBUG,
+	    "input_pvr: error setting position for writing %" PRIdMAX "\n", (intmax_t)pos);
+    return 0;
+  }
   if( this->rec_fd != -1 ) {
-    if( lseek (this->rec_fd, pos, SEEK_SET) != pos ) {
-      xprintf(this->stream->xine, XINE_VERBOSITY_DEBUG,
-              "input_pvr: error setting position for writing %" PRIdMAX "\n", (intmax_t)pos);
-      return 0;
-    }
     if( write(this->rec_fd, this->data, PVR_BLOCK_SIZE) < PVR_BLOCK_SIZE ) {
       xprintf(this->stream->xine, XINE_VERBOSITY_DEBUG,
 	      "input_pvr: short write to pvr file (out of disk space?)\n");
@@ -738,7 +742,7 @@ static int pvr_play_file(pvr_input_plugin_t *this, fifo_buffer_t *fifo, uint8_t
          this->play_fd = xine_open_cloexec(filename, O_RDONLY);
          if( this->play_fd == -1 ) {
            xprintf(this->stream->xine, XINE_VERBOSITY_LOG,
-                   _("input_pvr: error opening pvr file (%s)\n"), filename);
+		   _("input_pvr: error opening pvr file (%s)\n"), filename);
            free(filename);
            return 0;
          }
@@ -891,10 +895,7 @@ static void pvr_finish_recording (pvr_input_plugin_t *this) {
       if( this->save_page == (unsigned)-1 || i < this->save_page ) {
         lprintf("erasing old pvr file (%s)\n", src_filename);
 
-        if (remove(src_filename) < 0) {
-          xprintf(this->stream->xine, XINE_VERBOSITY_LOG,
-                  "input_pvr: error removing pvr file (%s)\n", src_filename);
-        }
+        remove(src_filename);
       } else {
 
         if( !this->save_name || !strlen(this->save_name) )
@@ -904,10 +905,7 @@ static void pvr_finish_recording (pvr_input_plugin_t *this) {
 
         lprintf("moving (%s) to (%s)\n", src_filename, dst_filename);
 
-        if (rename(src_filename, dst_filename) < 0) {
-          xprintf(this->stream->xine, XINE_VERBOSITY_LOG,
-                  "input_pvr: error renaming pvr file (%s->%s)\n", src_filename, dst_filename);
-        }
+        rename(src_filename,dst_filename);
         free(dst_filename);
       }
       free(src_filename);
@@ -934,7 +932,8 @@ static void pvr_finish_recording (pvr_input_plugin_t *this) {
 
       data.mode = 0;
       data.id = show->id;
-      strlcpy(data.name, show->base_name, sizeof(data.name));
+      strncpy(data.name, show->base_name, sizeof(data.name));
+      data.name[sizeof(data.name) - 1] = '\0';
 
       xine_event_send(this->stream, &event);
     } else {
@@ -975,8 +974,8 @@ static void pvr_event_handler (pvr_input_plugin_t *this) {
       /* make sure we are not paused */
       _x_set_speed(this->stream, XINE_SPEED_NORMAL);
 
-      if (v4l2_data->session_id != -1) {
-        if (v4l2_data->session_id != (int)this->session) {
+      if ( v4l2_data->session_id != -1) {
+        if( v4l2_data->session_id != this->session ) {
           /* if session changes -> closes the old one */
           pthread_mutex_lock(&this->lock);
           pvr_finish_recording(this);
@@ -1007,12 +1006,11 @@ static void pvr_event_handler (pvr_input_plugin_t *this) {
         this->input = v4l2_data->input;
 
         /* as of ivtv 0.10.6: must close and reopen to set input */
-        if (this->dev_fd >= 0)
-          close(this->dev_fd);
-        this->dev_fd = xine_open_cloexec(this->devname, O_RDWR);
+        close(this->dev_fd);
+        this->dev_fd = xine_open_cloexec(this->class->devname, O_RDWR);
         if (this->dev_fd < 0) {
           xprintf(this->stream->xine, XINE_VERBOSITY_DEBUG,
-                  "input_pvr: error opening device %s\n", this->devname );
+                  "input_pvr: error opening device %s\n", this->class->devname );
         } else {
           if( ioctl(this->dev_fd, VIDIOC_S_INPUT, &this->input) == 0 ) {
             lprintf("Tuner Input set to:%d\n", v4l2_data->input);
@@ -1030,7 +1028,7 @@ static void pvr_event_handler (pvr_input_plugin_t *this) {
       }
 
       /* change frequency */
-      if (v4l2_data->frequency != (uint32_t)-1 && v4l2_data->frequency != this->frequency) {
+      if (v4l2_data->frequency != -1 && v4l2_data->frequency != this->frequency) {
         double freq = (double)v4l2_data->frequency / 1000.0;
         struct v4l2_frequency vf;
         struct v4l2_tuner vt;
@@ -1066,7 +1064,7 @@ static void pvr_event_handler (pvr_input_plugin_t *this) {
 
 
     case XINE_EVENT_PVR_SAVE:
-      if (this->session != (uint32_t)-1) {
+      if( this->session != -1 ) {
         switch( save_data->mode ) {
           case 0:
             lprintf("saving from this point\n");
@@ -1125,10 +1123,7 @@ static void pvr_event_handler (pvr_input_plugin_t *this) {
 
                 lprintf("moving (%s) to (%s)\n", src_filename, dst_filename);
 
-                if (rename(src_filename, dst_filename) < 0) {
-                  xprintf(this->stream->xine, XINE_VERBOSITY_LOG,
-                          "input_pvr: error renaming pvr file (%s->%s)\n", src_filename, dst_filename);
-                }
+                rename(src_filename,dst_filename);
                 free(dst_filename);
                 free(src_filename);
               }
@@ -1158,13 +1153,11 @@ static void pvr_event_handler (pvr_input_plugin_t *this) {
        pthread_mutex_lock(&this->dev_lock);
 
        /* how lame. we must close and reopen to change bitrate. */
-       if (this->dev_fd >= 0)
-         close(this->dev_fd);
-       this->dev_fd = xine_open_cloexec(this->devname, O_RDWR);
+       close(this->dev_fd);
+       this->dev_fd = xine_open_cloexec(this->class->devname, O_RDWR);
        if (this->dev_fd == -1) {
-         pthread_mutex_unlock(&this->dev_lock);
          xprintf(this->stream->xine, XINE_VERBOSITY_LOG,
-                 _("input_pvr: error opening device %s\n"), this->devname );
+		 _("input_pvr: error opening device %s\n"), this->class->devname );
          return;
        }
 
@@ -1336,7 +1329,6 @@ static off_t pvr_plugin_get_length (input_plugin_t *this_gen) {
 }
 
 static uint32_t pvr_plugin_get_blocksize (input_plugin_t *this_gen) {
-  (void)this_gen;
   return PVR_BLOCK_SIZE;
 }
 
@@ -1349,9 +1341,6 @@ static const char* pvr_plugin_get_mrl (input_plugin_t *this_gen) {
 static int pvr_plugin_get_optional_data (input_plugin_t *this_gen,
 					  void *data, int data_type) {
 
-  (void)this_gen;
-  (void)data;
-  (void)data_type;
   return INPUT_OPTIONAL_UNSUPPORTED;
 }
 
@@ -1387,10 +1376,13 @@ static void pvr_plugin_dispose (input_plugin_t *this_gen ) {
 
   pvr_finish_recording(this);
 
-  _x_freep (&this->mrl);
-  _x_freep (&this->tmp_prefix);
-  _x_freep (&this->save_prefix);
-  _x_freep (&this->devname);
+  free (this->mrl);
+
+  if (this->tmp_prefix)
+    free (this->tmp_prefix);
+
+  if (this->save_prefix)
+    free (this->save_prefix);
 
   ite = xine_list_front (this->saved_shows);
   while (ite) {
@@ -1409,9 +1401,6 @@ static int pvr_plugin_open (input_plugin_t *this_gen ) {
   int                  err;
   struct ivtv_ioctl_codec codec;
 
-  _x_assert(this->dev_fd == -1);
-  _x_assert(this->pvr_running == 0);
-
   this->session = 0;
   this->rec_fd = -1;
   this->play_fd = -1;
@@ -1425,10 +1414,10 @@ static int pvr_plugin_open (input_plugin_t *this_gen ) {
 
   this->saved_id = 0;
 
-  this->dev_fd = xine_open_cloexec(this->devname, O_RDWR);
+  this->dev_fd = xine_open_cloexec(this->class->devname, O_RDWR);
   if (this->dev_fd == -1) {
     xprintf(this->stream->xine, XINE_VERBOSITY_LOG,
-            _("input_pvr: error opening device %s\n"), this->devname );
+	    _("input_pvr: error opening device %s\n"), this->class->devname );
     return 0;
   }
 
@@ -1448,19 +1437,13 @@ static int pvr_plugin_open (input_plugin_t *this_gen ) {
   }
 
   /* register our own scr provider */
-  _x_assert(this->scr == NULL);
   time = this->stream->xine->clock->get_current_time(this->stream->xine->clock);
   this->scr = pvrscr_init();
-  if (!this->scr)
-    return 0;
   this->scr->scr.start(&this->scr->scr, time);
   this->stream->xine->clock->register_scr(this->stream->xine->clock, &this->scr->scr);
   this->scr_tunning = 0;
 
-  _x_assert(this->event_queue == NULL);
   this->event_queue = xine_event_new_queue (this->stream);
-  if (!this->event_queue)
-    return 0;
 
   /* enable resample method */
   this->stream->xine->config->update_num(this->stream->xine->config,"audio.synchronization.av_sync_method",1);
@@ -1471,12 +1454,7 @@ static int pvr_plugin_open (input_plugin_t *this_gen ) {
 			     NULL, pvr_loop, this)) != 0) {
     xprintf (this->stream->xine, XINE_VERBOSITY_NONE,
 	     "input_pvr: can't create new thread (%s)\n", strerror(err));
-
-    this->pvr_running = 0;
-    close(this->dev_fd);
-    this->dev_fd = -1;
-
-    return 0;
+    _x_abort();
   }
 
   return 1;
@@ -1485,23 +1463,24 @@ static int pvr_plugin_open (input_plugin_t *this_gen ) {
 static input_plugin_t *pvr_class_get_instance (input_class_t *cls_gen, xine_stream_t *stream,
 				    const char *data) {
 
+  pvr_input_class_t   *cls = (pvr_input_class_t *) cls_gen;
   pvr_input_plugin_t  *this;
+  char                *mrl;
   char                *aux;
 
   if (strncasecmp (data, "pvr:/", 5))
     return NULL;
 
-  this = calloc(1, sizeof (pvr_input_plugin_t));
-  if (!this)
-    return NULL;
+  mrl = strdup(data);
+  aux = &mrl[5];
 
+  this = calloc(1, sizeof (pvr_input_plugin_t));
+  this->class        = cls;
   this->stream       = stream;
   this->dev_fd       = -1;
-  this->mrl          = strdup(data);
+  this->mrl          = mrl;
   this->max_page_age = 3;
 
-  aux = &this->mrl[5];
-
   /* decode configuration options from mrl */
   if( strlen(aux) ) {
     this->tmp_prefix = strdup(aux);
@@ -1552,16 +1531,6 @@ static input_plugin_t *pvr_class_get_instance (input_class_t *cls_gen, xine_stre
   pthread_cond_init  (&this->has_valid_data,NULL);
   pthread_cond_init  (&this->wake_pvr,NULL);
 
-  {
-    xine_cfg_entry_t dev;
-    if (xine_config_lookup_entry(stream->xine, "media.wintv_pvr.device", &dev) &&
-        dev.str_value && strlen(dev.str_value) > 0) {
-      this->devname = strdup(dev.str_value);
-    } else {
-      this->devname = strdup(PVR_DEVICE);
-    }
-  }
-
   return &this->input_plugin;
 }
 
@@ -1569,28 +1538,32 @@ static input_plugin_t *pvr_class_get_instance (input_class_t *cls_gen, xine_stre
 /*
  * plugin class functions
  */
-static void *init_plugin (xine_t *xine, const void *data) {
+static void *init_plugin (xine_t *xine, void *data) {
 
-  static const input_class_t input_pvr_class = {
-    .get_instance       = pvr_class_get_instance,
-    .identifier         = "pvr",
-    .description        = N_("WinTV-PVR 250/350 input plugin"),
-    .get_dir            = NULL,
-    .get_autoplay_list  = NULL,
-    .dispose            = NULL,
-    .eject_media        = NULL,
-  };
+  pvr_input_class_t  *this;
 
-  (void)data;
-  xine->config->register_filename(xine->config,
-                                  "media.wintv_pvr.device",
-                                  PVR_DEVICE, XINE_CONFIG_STRING_IS_DEVICE_NAME,
-                                  _("device used for WinTV-PVR 250/350 (pvr plugin)"),
-                                  _("The path to the device of your WinTV card."),
-                                  10, NULL,
-                                  NULL);
+  this = calloc(1, sizeof (pvr_input_class_t));
 
-  return (void *)&input_pvr_class;
+  this->xine   = xine;
+  this->config = xine->config;
+
+  this->devname = this->config->register_filename(this->config,
+				    "media.wintv_pvr.device",
+				    PVR_DEVICE, XINE_CONFIG_STRING_IS_DEVICE_NAME,
+				    _("device used for WinTV-PVR 250/350 (pvr plugin)"),
+				    _("The path to the device of your WinTV card."),
+				    10, NULL,
+				    NULL);
+
+  this->input_class.get_instance       = pvr_class_get_instance;
+  this->input_class.identifier         = "pvr";
+  this->input_class.description        = N_("WinTV-PVR 250/350 input plugin");
+  this->input_class.get_dir            = NULL;
+  this->input_class.get_autoplay_list  = NULL;
+  this->input_class.dispose            = default_input_class_dispose;
+  this->input_class.eject_media        = NULL;
+
+  return this;
 }
 
 /*
@@ -1600,6 +1573,6 @@ static void *init_plugin (xine_t *xine, const void *data) {
 const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */
   { PLUGIN_INPUT | PLUGIN_MUST_PRELOAD, 18, "pvr", XINE_VERSION_CODE, NULL, init_plugin },
-  { PLUGIN_NONE, 0, NULL, 0, NULL, NULL }
+  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
 
