@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2017 the xine project
+ * Copyright (C) 2000-2004 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -24,10 +24,6 @@
  * real work by goom author, JC Hoelt <jeko@free.fr>.
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
@@ -47,6 +43,7 @@
 */
 //#define BENCHMARK 1
 
+#include "config.h"
 #include <xine/xine_internal.h>
 #include <xine/xineutils.h>
 #include <xine/post.h>
@@ -60,7 +57,7 @@
 #define GOOM_HEIGHT 240
 
 /* colorspace conversion methods */
-static const char* const goom_csc_methods[]={
+static const char* goom_csc_methods[]={
   "Fast but not photorealistic",
   "Slow but looks better",
   "Mostly fast and good quality",
@@ -236,7 +233,7 @@ static void *goom_init_plugin(xine_t *xine, void *data)
 
 
   cfg->register_enum (cfg, "effects.goom.csc_method", 0,
-                           (char **)goom_csc_methods,
+                           goom_csc_methods,
                            _("colour space conversion method"),
                            _("You can choose the colour space conversion method used by goom.\n"
 			     "The available selections should be self-explaining."),
@@ -576,7 +573,7 @@ static void goom_port_put_buffer (xine_audio_port_t *port_gen,
               frame->proc_slice (frame, sptr);
             }
           }
-#if defined(ARCH_X86)
+
         } else if ((this->csc_method == 1) &&
             (xine_mm_accel() & MM_ACCEL_X86_MMX)) {
           int plane_ptr = 0;
@@ -597,7 +594,7 @@ static void goom_port_put_buffer (xine_audio_port_t *port_gen,
           }
 
           yuv444_to_yuy2(&this->yuv, frame->base[0], frame->pitches[0]);
-#endif /* ARCH_X86 */
+
         } else {
 
           while (goom_frame < goom_frame_end) {
