@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "config.h"
@@ -76,7 +76,6 @@ static void stats_picture (uint8_t * buffer)
 
 static void stats_user_data (uint8_t * buffer)
 {
-    (void)buffer;
     fprintf (stderr, " (user_data)\n");
 }
 
@@ -138,13 +137,11 @@ static void stats_sequence (uint8_t * buffer)
 
 static void stats_sequence_error (uint8_t * buffer)
 {
-    (void)buffer;
     fprintf (stderr, " (sequence_error)\n");
 }
 
 static void stats_sequence_end (uint8_t * buffer)
 {
-    (void)buffer;
     fprintf (stderr, " (sequence_end)\n");
 }
 
@@ -158,8 +155,6 @@ static void stats_group (uint8_t * buffer)
 static void stats_slice (int code, uint8_t * buffer)
 {
     /* fprintf (stderr, " (slice %d)\n", code); */
-    (void)code;
-    (void)buffer;
 }
 
 static void stats_sequence_extension (uint8_t * buffer)
@@ -183,32 +178,27 @@ static void stats_sequence_extension (uint8_t * buffer)
 
 static void stats_sequence_display_extension (uint8_t * buffer)
 {
-    (void)buffer;
     fprintf (stderr, " (sequence_display_extension)\n");
 }
 
 static void stats_quant_matrix_extension (uint8_t * buffer)
 {
-    (void)buffer;
     fprintf (stderr, " (quant_matrix_extension)\n");
 }
 
 static void stats_copyright_extension (uint8_t * buffer)
 {
-    (void)buffer;
     fprintf (stderr, " (copyright_extension)\n");
 }
 
 
 static void stats_sequence_scalable_extension (uint8_t * buffer)
 {
-    (void)buffer;
     fprintf (stderr, " (sequence_scalable_extension)\n");
 }
 
 static void stats_picture_display_extension (uint8_t * buffer)
 {
-    (void)buffer;
     fprintf (stderr, " (picture_display_extension)\n");
 }
 
