@@ -1,5 +1,5 @@
 /* kate: space-indent on; indent-width 2; mixedindent off; indent-mode cstyle; remove-trailing-space on;
- * Copyright (C) 2008-2020 the xine project
+ * Copyright (C) 2008 the xine project
  * Copyright (C) 2008 Christophe Thommeret <hftom@free.fr>
  *
  * This file is part of xine, a free video player.
@@ -22,12 +22,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "alterh264_decode.h"
-#include "group_vdpau.h"
 
 
 #define MAX_DPB_SIZE 16
@@ -65,61 +60,6 @@ static int nframes;
 static FILE *outfile;
 #endif
 
-static const uint8_t zigzag_4x4[16] = {
-  0, 1, 4, 8,
-  5, 2, 3, 6,
-  9, 12, 13, 10,
-  7, 11, 14, 15
-};
-
-static const uint8_t zigzag_8x8[64] = {
-  0, 1, 8, 16, 9, 2, 3, 10,
-  17, 24, 32, 25, 18, 11, 4, 5,
-  12, 19, 26, 33, 40, 48, 41, 34,
-  27, 20, 13, 6, 7, 14, 21, 28,
-  35, 42, 49, 56, 57, 50, 43, 36,
-  29, 22, 15, 23, 30, 37, 44, 51,
-  58, 59, 52, 45, 38, 31, 39, 46,
-  53, 60, 61, 54, 47, 55, 62, 63
-};
-
-static const uint8_t default_4x4_intra[16] = {
-  6, 13, 13, 20,
-  20, 20, 28, 28,
-  28, 28, 32, 32,
-  32, 37, 37, 42
-};
-
-static const uint8_t default_4x4_inter[16] = {
-  10, 14, 14, 20,
-  20, 20, 24, 24,
-  24, 24, 27, 27,
-  27, 30, 30, 34
-};
-
-static const uint8_t default_8x8_intra[64] = {
-  6, 10, 10, 13, 11, 13, 16, 16,
-  16, 16, 18, 18, 18, 18, 18, 23,
-  23, 23, 23, 23, 23, 25, 25, 25,
-  25, 25, 25, 25, 27, 27, 27, 27,
-  27, 27, 27, 27, 29, 29, 29, 29,
-  29, 29, 29, 31, 31, 31, 31, 31,
-  31, 33, 33, 33, 33, 33, 36, 36,
-  36, 36, 38, 38, 38, 40, 40, 42
-};
-
-static const uint8_t default_8x8_inter[64] = {
-  9, 13, 13, 15, 13, 15, 17, 17,
-  17, 17, 19, 19, 19, 19, 19, 21,
-  21, 21, 21, 21, 21, 22, 22, 22,
-  22, 22, 22, 22, 24, 24, 24, 24,
-  24, 24, 24, 24, 25, 25, 25, 25,
-  25, 25, 25, 27, 27, 27, 27, 27,
-  27, 28, 28, 28, 28, 28, 30, 30,
-  30, 30, 32, 32, 32, 33, 33, 35
-};
-
-
 
 /*-------- DPB -------------------------------------------*/
 static void
@@ -138,7 +78,7 @@ dpb_print (sequence_t * sequence)
     vdpau_accel_t *accel;
     if (vo)
       accel = (vdpau_accel_t *) vo->accel_data;
-    sf = (vo) ? accel->surface : (uint32_t)-1;
+    sf = (vo) ? accel->surface : -1;
     fprintf (stderr,
 	     "{ i:%d u:%d c:%d pn:%d-%d ir:%d-%d tpoc:%d bpoc:%d sf:%u }\n",
 	     i, frame->used, frame->completed, frame->PicNum[0],
@@ -526,7 +466,6 @@ parse_scaling_list (bits_reader_t * br, uint8_t * scaling_list, int len,
   int32_t delta_scale;
   uint8_t use_default_scaling_matrix_flag = 0;
   int i;
-  uint32_t u;
 
   const uint8_t *zigzag = (len == 64) ? zigzag_8x8 : zigzag_4x4;
 
@@ -554,28 +493,28 @@ parse_scaling_list (bits_reader_t * br, uint8_t * scaling_list, int len,
     case 1:
     case 2:
       {
-	for (u = 0; u < sizeof (default_4x4_intra); u++)
-	  scaling_list[zigzag_4x4[u]] = default_4x4_intra[u];
+	for (i = 0; i < sizeof (default_4x4_intra); i++)
+	  scaling_list[zigzag_4x4[i]] = default_4x4_intra[i];
 	break;
       }
     case 3:
     case 4:
     case 5:
       {
-	for (u = 0; u < sizeof (default_4x4_inter); u++)
-	  scaling_list[zigzag_4x4[u]] = default_4x4_inter[u];
+	for (i = 0; i < sizeof (default_4x4_inter); i++)
+	  scaling_list[zigzag_4x4[i]] = default_4x4_inter[i];
 	break;
       }
     case 6:
       {
-	for (u = 0; u < sizeof (default_8x8_intra); u++)
-	  scaling_list[zigzag_8x8[u]] = default_8x8_intra[u];
+	for (i = 0; i < sizeof (default_8x8_intra); i++)
+	  scaling_list[zigzag_8x8[i]] = default_8x8_intra[i];
 	break;
       }
     case 7:
       {
-	for (u = 0; u < sizeof (default_8x8_inter); u++)
-	  scaling_list[zigzag_8x8[u]] = default_8x8_inter[u];
+	for (i = 0; i < sizeof (default_8x8_inter); i++)
+	  scaling_list[zigzag_8x8[i]] = default_8x8_inter[i];
 	break;
       }
     }
@@ -588,34 +527,43 @@ static void
 scaling_list_fallback_A (uint8_t * scaling_lists_4x4,
 			 uint8_t * scaling_lists_8x8, int i)
 {
-  uint32_t j;
+  int j;
   switch (i)
   {
   case 0:
+    {
       for (j = 0; j < sizeof (default_4x4_intra); j++)
 	scaling_lists_4x4[(i * 16) + zigzag_4x4[j]] = default_4x4_intra[j];
       break;
+    }
   case 3:
+    {
       for (j = 0; j < sizeof (default_4x4_inter); j++)
 	scaling_lists_4x4[(i * 16) + zigzag_4x4[j]] = default_4x4_inter[j];
       break;
+    }
   case 1:
   case 2:
   case 4:
   case 5:
     memcpy (&scaling_lists_4x4[i * 16], &scaling_lists_4x4[(i - 1) * 16],
-	    16);
+	    6 * 16);
     break;
   case 6:
+    {
       for (j = 0; j < sizeof (default_8x8_intra); j++)
 	scaling_lists_8x8[(i - 6) * 64 + zigzag_8x8[j]] =
 	  default_8x8_intra[j];
       break;
+    }
   case 7:
+    {
       for (j = 0; j < sizeof (default_8x8_inter); j++)
 	scaling_lists_8x8[(i - 6) * 64 + zigzag_8x8[j]] =
 	  default_8x8_inter[j];
       break;
+    }
+
   }
 }
 
@@ -697,17 +645,9 @@ vui_parameters (sequence_t * seq, vui_param_t * vui)
     lprintf ("num_units_in_tick = %u\n", vui->num_units_in_tick);
     vui->time_scale = read_bits (br, 32);
     lprintf ("time_scale = %u\n", vui->time_scale);
-    if (vui->time_scale > 0) {
-      /* good: 2 * 1001 / 48000. */
-      seq->video_step = (uint64_t)90000 * 2
-                      * vui->num_units_in_tick / vui->time_scale;
-      if (seq->video_step < 90) {
-        /* bad: 2 * 1 / 60000. seen this once from broken h.264 video usability info (VUI).
-         * VAAPI seems to apply a similar HACK.*/
-        seq->video_step = (uint64_t)90000000 * 2
-                        * vui->num_units_in_tick / vui->time_scale;
-      }
-    }
+    if (vui->time_scale > 0)
+      seq->video_step =
+	180000. * (double) vui->num_units_in_tick / (double) vui->time_scale;
   }
 }
 
@@ -1004,8 +944,8 @@ pic_parameter_set (vdpau_h264_alter_decoder_t * this_gen)
 	   pic->redundant_pic_cnt_present_flag);
 
   uint32_t more = more_rbsp_data (&seq->br);
-  lprintf ("more bits = %u (buflen = %d) (still = %zd)\n", more,
-           seq->br.length, (ssize_t)(seq->br.start + seq->br.length - seq->br.buffer));
+  lprintf ("more bits = %u (buflen = %d) (still = %d)\n", more,
+	   seq->br.length, seq->br.start + seq->br.length - seq->br.buffer);
   if (more)
   {
     pic->transform_8x8_mode_flag = read_bits (&seq->br, 1);
@@ -1447,11 +1387,11 @@ decode_poc (vdpau_h264_alter_decoder_t * this_gen)
 
     if ((sl->pic_order_cnt_lsb < prevPicOrderCntLsb)
 	&& ((prevPicOrderCntLsb - sl->pic_order_cnt_lsb) >=
-	    (int32_t)(MaxPicOrderCntLsb / 2)))
+	    (MaxPicOrderCntLsb / 2)))
       seq->cur_pic.PicOrderCntMsb = prevPicOrderCntMsb + MaxPicOrderCntLsb;
     else if ((sl->pic_order_cnt_lsb > prevPicOrderCntLsb)
 	     && ((sl->pic_order_cnt_lsb - prevPicOrderCntLsb) >
-		 (int32_t)(MaxPicOrderCntLsb / 2)))
+		 (MaxPicOrderCntLsb / 2)))
       seq->cur_pic.PicOrderCntMsb = prevPicOrderCntMsb - MaxPicOrderCntLsb;
     else
       seq->cur_pic.PicOrderCntMsb = prevPicOrderCntMsb;
@@ -1749,8 +1689,6 @@ decode_render (vdpau_h264_alter_decoder_t * vd, int bad_frame)
       || vd->decoder_width != seq->coded_width
       || vd->decoder_height != seq->coded_height)
   {
-    if (accel->lock)
-      accel->lock (accel->vo_frame);
     if (vd->decoder != VDP_INVALID_HANDLE)
     {
       accel->vdp_decoder_destroy (vd->decoder);
@@ -1760,8 +1698,6 @@ decode_render (vdpau_h264_alter_decoder_t * vd, int bad_frame)
       accel->vdp_decoder_create (accel->vdp_device, seq->profile,
 				 seq->coded_width, seq->coded_height,
 				 sp->num_ref_frames, &vd->decoder);
-    if (accel->unlock)
-      accel->unlock (accel->vo_frame);
     if (st != VDP_STATUS_OK)
       fprintf (stderr, "vdpau_h264_alter : failed to create decoder !! %s\n",
 	       accel->vdp_get_error_string (st));
@@ -1864,14 +1800,10 @@ decode_render (vdpau_h264_alter_decoder_t * vd, int bad_frame)
     vbits[(i * 2) + 1].bitstream = seq->buf + seq->slices[i].buf_offset;
     vbits[(i * 2) + 1].bitstream_bytes = seq->slices[i].len;
   }
-  if (accel->lock)
-    accel->lock (accel->vo_frame);
   st =
     accel->vdp_decoder_render (vd->decoder, accel->surface,
-			       CAST_VdpPictureInfo_PTR &info,
+			       (VdpPictureInfo *) & info,
 			       seq->slices_count * 2, vbits);
-  if (accel->unlock)
-    accel->unlock (accel->vo_frame);
   if (st != VDP_STATUS_OK)
     lprintf ("**********************DECODING failed! - surface = %d - %s\n",
 	     accel->surface, accel->vdp_get_error_string (st));
@@ -2066,12 +1998,12 @@ parse_startcodes (vdpau_h264_alter_decoder_t * this_gen, uint8_t * buf,
 
 
 static void
-parse_codec_private (vdpau_h264_alter_decoder_t * this_gen, const uint8_t * buf,
+parse_codec_private (vdpau_h264_alter_decoder_t * this_gen, uint8_t * buf,
 		     uint32_t len)
 {
   sequence_t *sequence = (sequence_t *) & this_gen->sequence;
   bits_reader_set (&sequence->br, buf, len);
-  const uint8_t *buffer = buf;
+  uint8_t *buffer = buf;
   int i;
 
   lprintf ("parse_codec_private\n");
@@ -2115,7 +2047,7 @@ parse_codec_private (vdpau_h264_alter_decoder_t * this_gen, const uint8_t * buf,
 static void
 flush_buffer (sequence_t * seq)
 {
-  if (((int)seq->bufpos - seq->bufseek) >= seq->bufseek)
+  if ((seq->bufpos - seq->bufseek) >= seq->bufseek)
   {
     seq->bufsize = (seq->bufpos - seq->bufseek) + MIN_BUFFER_SIZE;
     lprintf ("buffer too short, have to allocate a new one.\n");
@@ -2184,7 +2116,7 @@ vdpau_h264_alter_decode_data (video_decoder_t * this_gen, buf_element_t * buf)
     {
       lprintf ("BUF_SPECIAL_DECODER_CONFIG\n");
       seq->flag_header = 1;
-      const uint8_t *codec_private = buf->decoder_info_ptr[2];
+      uint8_t *codec_private = buf->decoder_info_ptr[2];
       uint32_t codec_private_len = buf->decoder_info[2];
       if (codec_private_len > 0)
 	parse_codec_private (this, codec_private, codec_private_len);
@@ -2196,7 +2128,7 @@ vdpau_h264_alter_decode_data (video_decoder_t * this_gen, buf_element_t * buf)
     return;
 
   int size = seq->bufpos + buf->size;
-  if ((int)seq->bufsize < size)
+  if (seq->bufsize < size)
   {
     if (seq->bufsize > MAX_BUFFER_SIZE)
     {
@@ -2226,7 +2158,7 @@ vdpau_h264_alter_decode_data (video_decoder_t * this_gen, buf_element_t * buf)
       if (buf->pts)
 	seq->pic_pts = buf->pts;
       lprintf ("frame_end && seq->mode_frame\n");
-      uint32_t fhs;
+      int fhs;
       uint8_t tb;
       uint32_t j = 0;
       while (j < seq->bufpos)
@@ -2253,7 +2185,7 @@ vdpau_h264_alter_decode_data (video_decoder_t * this_gen, buf_element_t * buf)
     return;
   }
 
-  while (seq->bufseek <= (int)seq->bufpos - 4)
+  while (seq->bufseek <= seq->bufpos - 4)
   {
     uint8_t *buffer = seq->buf + seq->bufseek;
     if (buffer[0] == 0 && buffer[1] == 0 && buffer[2] == 1)
@@ -2311,7 +2243,7 @@ vdpau_h264_alter_flush (video_decoder_t * this_gen)
 {
   vdpau_h264_alter_decoder_t *this = (vdpau_h264_alter_decoder_t *) this_gen;
 
-  lprintf ("vdpau_h264_alter_flush\n");
+  printf ("vdpau_h264_alter_flush\n");
   dpb_draw_frames (this, MAX_POC, DPB_DRAW_REFS);
 }
 
@@ -2336,7 +2268,7 @@ static void
 vdpau_h264_alter_discontinuity (video_decoder_t * this_gen)
 {
   vdpau_h264_alter_decoder_t *this = (vdpau_h264_alter_decoder_t *) this_gen;
-  lprintf ("vdpau_h264_alter_discontinuity\n");
+  printf ("vdpau_h264_alter_discontinuity\n");
 
   dpb_clear_all_pts (&this->sequence);
   this->sequence.reset = VO_NEW_SEQUENCE_FLAG;
@@ -2356,12 +2288,8 @@ vdpau_h264_alter_dispose (video_decoder_t * this_gen)
 
   if ((this->decoder != VDP_INVALID_HANDLE) && this->sequence.accel_vdpau)
   {
-    if (this->sequence.accel_vdpau->lock)
-      this->sequence.accel_vdpau->lock (this->sequence.accel_vdpau->vo_frame);
     this->sequence.accel_vdpau->vdp_decoder_destroy (this->decoder);
     this->decoder = VDP_INVALID_HANDLE;
-    if (this->sequence.accel_vdpau->unlock)
-      this->sequence.accel_vdpau->unlock (this->sequence.accel_vdpau->vo_frame);
   }
   reset_sequence (&this->sequence);
 
@@ -2392,44 +2320,31 @@ open_plugin (video_decoder_class_t * class_gen, xine_stream_t * stream)
 
   vdpau_h264_alter_decoder_t *this;
 
-  (void)class_gen;
-
   /* the videoout must be vdpau-capable to support this decoder */
   if (!
-      (stream->video_out->
-       get_capabilities (stream->video_out) & VO_CAP_VDPAU_H264))
+      (stream->video_driver->
+       get_capabilities (stream->video_driver) & VO_CAP_VDPAU_H264))
     return NULL;
 
   /* now check if vdpau has free decoder resource */
   vo_frame_t *img =
-    stream->video_out->get_frame (stream->video_out, 1920, 1080, 1, XINE_IMGFMT_VDPAU,
-                                  VO_BOTH_FIELDS | VO_GET_FRAME_MAY_FAIL);
-  if (!img) {
-    return NULL;
-  }
+    stream->video_out->get_frame (stream->video_out, 1920, 1080, 1,
+				  XINE_IMGFMT_VDPAU, VO_BOTH_FIELDS);
   vdpau_accel_t *accel = (vdpau_accel_t *) img->accel_data;
   int runtime_nr = accel->vdp_runtime_nr;
   img->free (img);
   VdpDecoder decoder;
-  VdpStatus st;
-  if (accel->lock)
-    accel->lock (accel->vo_frame);
-  st =accel->vdp_decoder_create (accel->vdp_device,
+  VdpStatus st =
+    accel->vdp_decoder_create (accel->vdp_device,
 			       VDP_DECODER_PROFILE_H264_MAIN, 1920, 1080, 16,
 			       &decoder);
-  if (accel->unlock)
-    accel->unlock (accel->vo_frame);
   if (st != VDP_STATUS_OK)
   {
     fprintf (stderr, "can't create vdpau decoder!\n");
     return NULL;
   }
 
-  if (accel->lock)
-    accel->lock (accel->vo_frame);
   accel->vdp_decoder_destroy (decoder);
-  if (accel->unlock)
-    accel->unlock (accel->vo_frame);
 
   this =
     (vdpau_h264_alter_decoder_t *) calloc (1,
@@ -2443,6 +2358,7 @@ open_plugin (video_decoder_class_t * class_gen, xine_stream_t * stream)
   this->video_decoder.dispose = vdpau_h264_alter_dispose;
 
   this->stream = stream;
+  this->class = (vdpau_h264_alter_class_t *) class_gen;
 
   int i;
   for (i = 0; i < 16; i++)
@@ -2483,22 +2399,59 @@ open_plugin (video_decoder_class_t * class_gen, xine_stream_t * stream)
  * This function allocates a private video decoder class and initializes
  * the class's member functions.
  */
-void *
-h264_alter_init_plugin (xine_t * xine, const void *data)
+static void *
+init_plugin (xine_t * xine, void *data)
 {
-  (void)xine;
-  (void)data;
 
-  static const video_decoder_class_t decode_video_vdpau_h264_alter_class = {
-    .open_plugin = open_plugin,
-    .identifier  = "vdpau_h264_alter",
-    .description =
-      N_
-      ("vdpau_h264_alter: H264 decoder plugin using VDPAU hardware decoding.\n"
-       "Must be used along with video_out_vdpau."),
-    .dispose = NULL,
-  };
+  vdpau_h264_alter_class_t *this;
 
-  return (void *)&decode_video_vdpau_h264_alter_class;
+  this =
+    (vdpau_h264_alter_class_t *) calloc (1,
+					 sizeof (vdpau_h264_alter_class_t));
+
+  this->decoder_class.open_plugin = open_plugin;
+  this->decoder_class.identifier = "vdpau_h264_alter";
+  this->decoder_class.description =
+    N_
+    ("vdpau_h264_alter: H264 decoder plugin using VDPAU hardware decoding.\n"
+     "Must be used along with video_out_vdpau.");
+  this->decoder_class.dispose = default_video_decoder_class_dispose;
+
+  return this;
 }
 
+
+/*
+ * This is a list of all of the internal xine video buffer types that
+ * this decoder is able to handle. Check src/xine-engine/buffer.h for a
+ * list of valid buffer types (and add a new one if the one you need does
+ * not exist). Terminate the list with a 0.
+ */
+static const uint32_t video_types[] = {
+  BUF_VIDEO_H264,
+  0
+};
+
+
+/*
+ * This data structure combines the list of supported xine buffer types and
+ * the priority that the plugin should be given with respect to other
+ * plugins that handle the same buffer type. A plugin with priority (n+1)
+ * will be used instead of a plugin with priority (n).
+ */
+static const decoder_info_t dec_info_video = {
+  video_types,			/* supported types */
+  9				/* priority        */
+};
+
+
+/*
+ * The plugin catalog entry. This is the only information that this plugin
+ * will export to the public.
+ */
+const plugin_info_t xine_plugin_info[] EXPORTED = {
+  /* { type, API, "name", version, special_info, init_function } */
+  {PLUGIN_VIDEO_DECODER, 19, "vdpau_h264_alter", XINE_VERSION_CODE,
+   &dec_info_video, init_plugin},
+  {PLUGIN_NONE, 0, "", 0, NULL, NULL}
+};
