@@ -1,6 +1,6 @@
 /* kate: tab-indent on; indent-width 4; mixedindent off; indent-mode cstyle; remove-trailing-space on; */
 /*
- * Copyright (C) 2008-2018 the xine project
+ * Copyright (C) 2008 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -26,6 +26,9 @@
 //#define LOG
 #define LOG_MODULE "vdpau_h264"
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -69,6 +72,62 @@ enum aspect_ratio
 
 
 
+static const uint8_t zigzag_4x4[16] = {
+  0, 1, 4, 8,
+  5, 2, 3, 6,
+  9, 12, 13, 10,
+  7, 11, 14, 15
+};
+
+static const uint8_t zigzag_8x8[64] = {
+  0, 1, 8, 16, 9, 2, 3, 10,
+  17, 24, 32, 25, 18, 11, 4, 5,
+  12, 19, 26, 33, 40, 48, 41, 34,
+  27, 20, 13, 6, 7, 14, 21, 28,
+  35, 42, 49, 56, 57, 50, 43, 36,
+  29, 22, 15, 23, 30, 37, 44, 51,
+  58, 59, 52, 45, 38, 31, 39, 46,
+  53, 60, 61, 54, 47, 55, 62, 63
+};
+
+static const uint8_t default_4x4_intra[16] = {
+  6, 13, 13, 20,
+  20, 20, 28, 28,
+  28, 28, 32, 32,
+  32, 37, 37, 42
+};
+
+static const uint8_t default_4x4_inter[16] = {
+  10, 14, 14, 20,
+  20, 20, 24, 24,
+  24, 24, 27, 27,
+  27, 30, 30, 34
+};
+
+static const uint8_t default_8x8_intra[64] = {
+  6, 10, 10, 13, 11, 13, 16, 16,
+  16, 16, 18, 18, 18, 18, 18, 23,
+  23, 23, 23, 23, 23, 25, 25, 25,
+  25, 25, 25, 25, 27, 27, 27, 27,
+  27, 27, 27, 27, 29, 29, 29, 29,
+  29, 29, 29, 31, 31, 31, 31, 31,
+  31, 33, 33, 33, 33, 33, 36, 36,
+  36, 36, 38, 38, 38, 40, 40, 42
+};
+
+static const uint8_t default_8x8_inter[64] = {
+  9, 13, 13, 15, 13, 15, 17, 17,
+  17, 17, 19, 19, 19, 19, 19, 21,
+  21, 21, 21, 21, 21, 22, 22, 22,
+  22, 22, 22, 22, 24, 24, 24, 24,
+  24, 24, 24, 24, 25, 25, 25, 25,
+  25, 25, 25, 27, 27, 27, 27, 27,
+  27, 28, 28, 28, 28, 28, 30, 30,
+  30, 30, 32, 32, 32, 33, 33, 35
+};
+
+
+
 typedef struct
 {
   uint8_t aspect_ratio_info;
@@ -275,10 +334,19 @@ typedef struct
 } sequence_t;
 
 
+
+typedef struct
+{
+  video_decoder_class_t decoder_class;
+} vdpau_h264_alter_class_t;
+
+
+
 typedef struct vdpau_mpeg12_decoder_s
 {
   video_decoder_t video_decoder;	/* parent video decoder structure */
 
+  vdpau_h264_alter_class_t *class;
   xine_stream_t *stream;
 
   sequence_t sequence;
